@@ -1,7 +1,7 @@
 #include "arg.ih"
 
 int Arg::setOptionType(string const &optString,
-                            Arg::LongOption const &longOption) throw (Errno)
+                            Arg::LongOption const &longOption)
 {
     string::size_type pos = optString.find_first_of(longOption.d_optionChar);
 
