@@ -3,5 +3,5 @@
 void Glob::copy(Glob const &other)
 {
     d_share = other.d_share;
-    d_share->users++;
+    ++d_share->users;
 }
