@@ -10,6 +10,11 @@
 using namespace std;
 using namespace FBB;
 
+Glob makeGlob(char const *pat)
+{
+    return Glob(pat, Glob::PERIOD, Glob::DEFAULT);
+}
+
 int main(int argc, char **argv)
 try
 {
@@ -19,26 +24,30 @@ try
         return 1;
     }
 
-    cout << "General:\n";
+    cout << "\nGeneral:\n";
 
     Glob general;
-    general.verify();
 
     for (size_t idx = 0; idx < general.size(); idx++)
-        cout << idx << ": " << general[idx] << endl;
+        cout << idx << ": " << general[idx] << '\n';
 
-    cout << "Pattern: " << argv[1] << "\n";
+    cout << "\nPattern: " << argv[1] << "\n";
 
-    Glob pattern(argv[1], Glob::PERIOD, Glob::DEFAULT);
-    pattern.verify();
+    Glob pattern(makeGlob(argv[1]));
+    Glob copy(pattern);
+    copy = general;
 
     for (size_t idx = 0; idx < pattern.size(); idx++)
-        cout << idx << ": " << pattern[idx] << endl;
+        cout << idx << ": " << pattern[idx] << '\n';
+
+    cout << "\nThe next glob will fail, this is intended behavior\n";
+
+    Glob fails("*", 1023);
 
     return 0;
 }
 catch (Errno const &err)
 {
-    cout << err.what() << endl;
+    cout << err.what() << '\n';
     return err.which();
 }
