@@ -1,6 +1,6 @@
 #include "localclientsocket.ih"
 
-int LocalClientSocket::connect() throw (Errno)
+int LocalClientSocket::connect()
 {
     if (::connect(socket(), sockaddrPtr(), size()) < 0)
         throw Errno("LocalClientSocket::connect()");
