@@ -4,7 +4,7 @@ string String::uc(string const &lhs)
 {
     string ret(lhs);
 
-    for_each(ret.begin(), ret.end(), Wrap1<char>(&String::toupper));
+    for_each(ret.begin(), ret.end(), FnWrap1<char &>(&String::toupper));
 
     return ret;
 }
